"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const log_1 = require("../log");
class Image {
    constructor(image) {
        this.image = image;
    }
    inspect() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.image) {
                throw new Error('container is null.');
            }
            try {
                return yield this.image.inspect();
            }
            catch (error) {
                log_1.Log.error(error);
            }
            return "";
        });
    }
    history() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.image) {
                throw new Error('container is null.');
            }
            const data = [];
            try {
                const layers = yield this.image.history();
                if (!layers) {
                    return data;
                }
                layers.forEach((layer, index) => {
                    if (layer) {
                        const size = (layer.Size / 1000 / 1000).toFixed(2) + ' MB';
                        data.push([(layers.length - index).toString(), size.toString(), layer.CreatedBy.toString()]);
                    }
                });
                data.push(['Order', 'Size', 'Layer']);
                data.reverse();
            }
            catch (error) {
                log_1.Log.error(error);
                data.push(['Error', error.errno]);
            }
            return data;
        });
    }
}
exports.default = Image;
