"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("./color");
const blessed = require('blessed');
const contrib = require('blessed-contrib');
class WidgetRender {
    static screen(title) {
        return blessed.screen({ smartCSR: true, fullUnicode: true, autoPadding: true, title: title });
    }
    static menuBar(parent, commands) {
        const bar = blessed.listbar({
            parent: parent, top: 0, left: 0, right: 0, height: 'shrink',
            mouse: true, keys: false, border: 'line',
            style: {
                item: { bg: color_1.Color.yellow, fg: color_1.Color.black, hover: { bg: color_1.Color.blue } },
                selected: { bg: color_1.Color.blue }
            },
            commands: commands
        });
        bar.focus();
        return bar;
    }
    static table(parent, location, label = '', selectedColor) {
        const cell = selectedColor ? { fg: color_1.Color.magenta, selected: { bg: selectedColor } } : { fg: color_1.Color.magenta };
        return blessed.listtable({
            parent: parent,
            top: location.top, left: location.left, width: location.width, height: location.height,
            border: 'line', align: Align.left,
            tags: true, keys: true, mouse: true,
            style: {
                fg: color_1.Color.white,
                header: { fg: color_1.Color.blue, bold: true, bg: color_1.Color.black },
                border: { fg: color_1.Color.black },
                cell: cell
            },
            label: label
        });
    }
    ;
    static text(parent, location, content) {
        return blessed.text({
            parent: parent,
            top: location.top, left: location.left, right: location.right, bottom: location.bottom, width: location.width, height: location.height,
            tags: true, keys: true,
            content: content
        });
    }
    ;
    static drawInfomation(parent, location, datas, padLenght = 10) {
        let content = '';
        datas.forEach((data) => {
            content = content + color_1.ColorText.blue(data[0].padEnd(padLenght, ' ')) + data[1] + "\n";
        });
        return this.text(parent, location, content);
    }
    static line(location, color, label, showLegend = false) {
        return new contrib.line({
            top: location.top, left: location.left, right: location.right, bottom: location.bottom, width: location.width, height: location.height,
            style: {
                line: color,
                text: color_1.Color.green,
                baseline: [color_1.Color.gray]
            },
            border: {
                type: "line",
                fg: color_1.Color.cyan
            },
            showNthLabel: 1,
            label: ' ' + label + ' ',
            xLabelPadding: 3,
            showLegend: showLegend,
            legend: { width: 4 }
        });
    }
    ;
    static donut(location) {
        return contrib.donut({
            top: location.top, left: location.left, right: location.right, bottom: location.bottom, width: location.width, height: location.height,
            radius: 10,
            arcWidth: 3,
            remainColor: color_1.Color.white,
            yPadding: 2,
            data: []
        });
    }
    static box(parent) {
        return blessed.box({
            parent: parent,
            align: Align.center,
            top: 2, left: 0, width: '100%', height: 'shrink',
            border: 'line',
            alwaysScroll: false, scrollable: true, scrollstep: 1,
            scrollbar: {
                ch: ' '
            }
        });
    }
    static inspectBox(parent, location, label) {
        return this.drawBox(parent, location, '', label);
    }
    ;
    static helpBox(parent, content) {
        const location = { top: 'center', left: 'center', width: '60%', height: 24 };
        return this.drawBox(parent, location, content, ' Help ', color_1.Color.black);
    }
    static drawBox(parent, location, content, label, bg) {
        return blessed.box({
            parent: parent,
            label: label,
            scrollable: true, scrollstep: 1,
            top: location.top, left: location.left, right: location.right, bottom: location.bottom, width: location.width, height: location.height,
            align: Align.left,
            border: { type: 'line', fg: color_1.Color.cyan },
            content: content,
            style: { bg: bg },
            keys: true,
            mouse: true,
            vi: true,
            alwaysScroll: true,
            scrollbar: {
                ch: ' ',
                inverse: true
            }
        });
    }
}
exports.WidgetRender = WidgetRender;
var Align;
(function (Align) {
    Align["left"] = "left";
    Align["right"] = "right";
    Align["center"] = "center";
})(Align = exports.Align || (exports.Align = {}));
