"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const widgetrender_1 = require("../common/widgetrender");
const widget_1 = require("./widget");
const dockerode_1 = require("../common/docker/dockerode");
const log_1 = require("../common/log");
const container_1 = require("../common/docker/container");
const inversify_1 = require("inversify");
const color_1 = require("../common/color");
let ContainerWidget = class ContainerWidget extends widget_1.Widget {
    constructor() {
        super(...arguments);
        this.selectId = "";
    }
    getCommandName() {
        return "Containers";
    }
    getCommandKey() {
        return {
            keys: ["c"],
            callback: () => {
                if (!this.table) {
                    this.render();
                    this.table.focus();
                }
                this.active();
            }
        };
    }
    getAllElements() {
        return [this.table, this.text, this.mem, this.cpu, this.net, this.log];
    }
    renderWidget(box) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const location = { top: 0, left: 0, width: "100%-2", height: "40%-2" };
                this.table = widgetrender_1.WidgetRender.table(box, location, "Containers");
                const data = yield dockerode_1.Dockerode.singleton.listContainers();
                this.table.setData(data);
                this.monitorContainer();
                this.table.on("select", (container) => {
                    this.showSelectContainer(container);
                });
            }
            catch (error) {
                log_1.Log.error(error);
            }
            this.text = widgetrender_1.WidgetRender.text(box, { top: "40%-2", left: 0, width: "100%-2", height: 2 }, "{bold}✔  Container Stats{bold}");
            this.cpu = widgetrender_1.WidgetRender.line({ top: "40%", left: 0, width: "50%-1", height: "30%" }, color_1.Color.red, "CPU Usage (%)");
            box.append(this.cpu);
            this.mem = widgetrender_1.WidgetRender.line({ top: "40%", right: 0, width: "50%-1", height: "30%" }, color_1.Color.magenta, "Memory Usage (MB)");
            box.append(this.mem);
            this.net = widgetrender_1.WidgetRender.line({ left: 0, bottom: 0, width: "50%-1", height: "30%-1" }, color_1.Color.white, "Network Usage (KB)", true);
            box.append(this.net);
            this.log = widgetrender_1.WidgetRender.inspectBox(box, { right: 0, bottom: 0, width: "50%-1", height: "30%-1" }, " Inspect ");
        });
    }
    monitorContainer() {
        return __awaiter(this, void 0, void 0, function* () {
            dockerode_1.Dockerode.singleton.monitor(() => __awaiter(this, void 0, void 0, function* () {
                const data = yield dockerode_1.Dockerode.singleton.listContainers();
                const childOffset = this.table.childOffset;
                this.table.setData(data);
                this.table.move(childOffset - 1);
            }));
        });
    }
    showSelectContainer(containerItem) {
        return __awaiter(this, void 0, void 0, function* () {
            const selectId = containerItem.content.substring(0, 8);
            if (this.selectId == selectId) {
                return;
            }
            this.selectId = selectId;
            this.clearData();
            this.text.setContent("{bold}✔ Container Stats (" + selectId + "){bold}");
            this.refresh();
            const container = dockerode_1.Dockerode.singleton.getContainer(selectId);
            if (!this.isRunning(selectId)) {
                return;
            }
            const inspectData = yield container.inspect();
            this.log.setContent(inspectData);
            yield this.showStatsCharts(container);
        });
    }
    clearData() {
        if (this.stream) {
            this.stream.end();
        }
        this.cpu.setData(container_1.Usage.EMPTY);
        this.mem.setData(container_1.Usage.EMPTY);
        this.net.setData(container_1.EMPTY_NET_DATA);
        this.log.setContent("");
    }
    showStatsCharts(container) {
        return __awaiter(this, void 0, void 0, function* () {
            this.stream = yield container.stat();
            this.stream.ondata((cpuuage, memUsage, txData, rxData) => {
                this.cpu.setData(cpuuage);
                this.mem.setData(memUsage);
                this.net.setData([txData, rxData]);
                this.refresh();
            });
        });
    }
    isRunning(selectId) {
        if (this.table) {
            const row = this.table.rows.find((row) => row[0] === selectId);
            if (row) {
                return row[5].indexOf("running") >= 0;
            }
        }
        return false;
    }
};
ContainerWidget = __decorate([
    inversify_1.injectable()
], ContainerWidget);
exports.ContainerWidget = ContainerWidget;
