"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const widgetrender_1 = require("../common/widgetrender");
const color_1 = require("../common/color");
const widget_1 = require("./widget");
const dockerode_1 = require("../common/docker/dockerode");
const log_1 = require("../common/log");
const inversify_1 = require("inversify");
const os = require('os');
const os_utils_1 = __importDefault(require("os-utils"));
const utils_1 = require("../common/utils");
let HomeWidget = class HomeWidget extends widget_1.Widget {
    constructor() {
        super(...arguments);
        this.allElements = [];
    }
    getCommandName() {
        return "Dashboard";
    }
    getCommandKey() {
        return {
            keys: ["d"],
            callback: () => {
                this.active();
            }
        };
    }
    getAllElements() {
        return this.allElements;
    }
    renderWidget(box) {
        return __awaiter(this, void 0, void 0, function* () {
            this.allElements.push(widgetrender_1.WidgetRender.text(box, { top: 1, left: 1, width: "100%-5", height: 2 }, color_1.ColorText.title('Host Information')));
            this.showCPUUasge(box);
            this.showSystemInfomation(box);
            this.allElements.push(widgetrender_1.WidgetRender.text(box, { top: 10, left: 1, width: "100%-5", height: 2 }, color_1.ColorText.title('Docker Engine')));
            this.showDockerInfomation(box);
            this.allElements.push(widgetrender_1.WidgetRender.text(box, { top: 20, left: 1, width: "100%-4", height: 2 }, color_1.ColorText.title('Statistics')));
            this.showStatistics(box);
            this.refresh();
        });
    }
    ;
    showCPUUasge(box) {
        return __awaiter(this, void 0, void 0, function* () {
            const donut = widgetrender_1.WidgetRender.donut({ top: 2, left: 53, width: 50, height: 10 });
            box.append(donut);
            donut.setData([
                { percent: 0, label: 'CPU Usage', color: color_1.Color.green },
                { percent: 0, label: 'MEM Usage', color: color_1.Color.cyan }
            ]);
            const interval = setInterval(() => {
                os_utils_1.default.cpuUsage((v) => {
                    const cpuusage = (v * 100.0).toFixed(2);
                    const memusage = ((os.totalmem() - os.freemem()) / os.totalmem() * 100).toFixed(2);
                    donut.setData([
                        { percent: cpuusage, label: 'CPU Usage', color: color_1.Color.green },
                        { percent: memusage, label: 'MEM Usage', color: color_1.Color.cyan }
                    ]);
                    this.refresh();
                });
            }, 1000);
            this.allElements.push(donut);
        });
    }
    showSystemInfomation(box) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = [
                ['Host Name', os.hostname()],
                ['OS', os.platform() + '-' + os.arch() + ' ' + os.release()],
                ['Total CPU', this.getCPUs()],
                ['Total Memory', (os.totalmem() / 1000 / 1000 / 1000).toFixed(2) + ' GB'],
                ['Up Time', (os.uptime() / 60 / 60).toFixed(0) + ' Hours']
            ];
            const location = { top: 3, left: 3, width: 50, height: 6 };
            this.allElements.push(widgetrender_1.WidgetRender.drawInfomation(box, location, data, 22));
        });
    }
    showDockerInfomation(box) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const data = yield dockerode_1.Dockerode.singleton.getDockerVersion();
                const location = { top: 12, left: 3, width: 50, height: 6 };
                this.allElements.push(widgetrender_1.WidgetRender.drawInfomation(box, location, data, 22));
                this.refresh();
            }
            catch (error) {
                log_1.Log.info(error);
            }
        });
    }
    getCPUs() {
        const cups = os.cpus();
        return (cups && cups.length) ? cups.length.toString() : "0";
    }
    showStatistics(box) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const location = { top: 22, left: 1, width: '100%-4', height: 4 };
                const statisticsTable = widgetrender_1.WidgetRender.table(box, location);
                const data = yield dockerode_1.Dockerode.singleton.getStatistics();
                statisticsTable.setData(data);
                setInterval(() => __awaiter(this, void 0, void 0, function* () {
                    const data = yield dockerode_1.Dockerode.singleton.getStatistics();
                    statisticsTable.setData(data);
                }), utils_1.REFRESH_INTERNAL);
                this.allElements.push(statisticsTable);
                this.refresh();
            }
            catch (error) {
                log_1.Log.info(error);
            }
        });
    }
};
HomeWidget = __decorate([
    inversify_1.injectable()
], HomeWidget);
exports.HomeWidget = HomeWidget;
